@@ -252,7 +252,7 @@ as_one_logical <- function(x, allow_na = FALSE) {
   x <- as.logical(x)
   if (length(x) != 1L || anyNA(x) && !allow_na) {
     s <- deparse_combine(s, max_char = 100L)
-    stop2("Cannot coerce ", s, " to a single logical value.")
+    stop2("Cannot coerce '", s, "' to a single logical value.")
   }
   x
 }
@@ -263,7 +263,7 @@ as_one_numeric <- function(x, allow_na = FALSE) {
   x <- SW(as.numeric(x))
   if (length(x) != 1L || anyNA(x) && !allow_na) {
     s <- deparse_combine(s, max_char = 100L)
-    stop2("Cannot coerce ", s, " to a single numeric value.")
+    stop2("Cannot coerce '", s, "' to a single numeric value.")
   }
   x
 }
@@ -274,7 +274,19 @@ as_one_character <- function(x, allow_na = FALSE) {
   x <- as.character(x)
   if (length(x) != 1L || anyNA(x) && !allow_na) {
     s <- deparse_combine(s, max_char = 100L)
-    stop2("Cannot coerce ", s, " to a single character value.")
+    stop2("Cannot coerce '", s, "' to a single character value.")
+  }
+  x
+}
+
+# coerce 'x' to a single character variable name
+as_one_variable <- function(x, allow_na = TRUE) {
+  x <- as_one_character(x)
+  if (x == "NA" && allow_na) {
+    return(x)
+  }
+  if (!nzchar(x) || !is_equal(x, all_vars(x))) {
+    stop2("Cannot coerce '", x, "' to a single variable name.")
   }
   x
 }
@@ -327,6 +339,11 @@ subset_keep_attr <- function(x, y) {
   x
 }
 
+'%||%' <- function(x, y) {
+  if (is.null(x)) x <- y
+  x
+}
+
 # check if 'x' is a whole number (integer)
 is_wholenumber <- function(x, tol = .Machine$double.eps) {  
   if (is.numeric(x)) {
@@ -579,6 +596,18 @@ named_list <- function(names, values = NULL) {
   setNames(values, names)
 }
 
+# is an object named?
+is_named <- function(x) {
+  names <- names(x)
+  if (is.null(names)) {
+    return(FALSE)
+  }
+  if (any(!nzchar(names) | is.na(names))) {
+    return(FALSE)
+  }
+  TRUE
+}
+
 #' Execute a Function Call
 #'
 #' Execute a function call similar to \code{\link{do.call}}, but without
