@@ -25,22 +25,25 @@ restructure <- function(x, rstr_summary = FALSE) {
     x$version <- list(brms = x$version)
   }
   current_version <- utils::packageVersion("brms") 
-  if (x$version$brms >= current_version) {
+  restr_version <- get_restructure_version(x)
+  if (restr_version >= current_version) {
+    # object is up to date with the current brms version
     return(x)
-  } 
-  restructured <- attr(x, "restructured")
-  if (!is.package_version(restructured) || restructured < current_version) {
-    # object is not up to date with the current brms version
-    if (x$version$brms < "2.0.0") {
-      x <- restructure_v1(x)
-    }
-    if (x$version$brms < "3.0.0") {
-      x <- restructure_v2(x)
-    }
   }
+  if (restr_version < "2.0.0") {
+    x <- restructure_v1(x)
+  }
+  if (restr_version < "3.0.0") {
+    x <- restructure_v2(x)
+  }
+  # remember the version with which the object was restructured
+  x$version$restructure <- current_version
+  # remove unused attribute
+  attr(x, "restructured") <- NULL
+  # optionally also restructure the rstan summary
+  # TODO: remove at some point as summary.brmsfit no longer requires it
   stan_env <- attributes(x$fit)$.MISC
   if (rstr_summary && exists("summary", stan_env)) {
-    # TODO: remove at some point as summary.brmsfit no longer requires it
     stan_summary <- get("summary", stan_env)
     old_parnames <- rownames(stan_summary$msd)
     if (!identical(old_parnames, parnames(x))) {
@@ -49,15 +52,15 @@ restructure <- function(x, rstr_summary = FALSE) {
       remove("summary", pos = stan_env)
     }
   }
-  structure(x, restructured = current_version)
+  x
 }
 
 restructure_v2 <- function(x) {
   # restructure models fitted with brms 2.x
   x$formula <- update_old_family(x$formula)
-  bterms <- parse_bf(x$formula)
+  bterms <- SW(parse_bf(x$formula))
   pars <- parnames(x)
-  version <- x$version$brms
+  version <- get_restructure_version(x)
   if (version <= "2.1.1") {
     x <- do_renaming(x, change_old_bsp(pars))
   }
@@ -106,7 +109,7 @@ restructure_v2 <- function(x) {
     # internal handling of special effects terms has changed
     # this requires updating the 'terms' attribute of the data
     x$data <- rm_attr(x$data, c("brmsframe", "terms"))
-    x$data <- update_data(x$data, bterms) 
+    x$data <- validate_data(x$data, bterms) 
   }
   if (version <= "2.8.8") {
     if (any(grepl("^loclev(\\[|_|$)", pars))) {
@@ -128,12 +131,31 @@ restructure_v2 <- function(x) {
       x$formula <- SW(validate_formula(x$formula, data = x$data))
     }
   }
+  if (version <= "2.11.1") {
+    # 'autocor' was integrated into the formula interface
+    x$formula <- SW(validate_formula(x$formula))
+    x$data2 <- validate_data2(
+      data2 = list(), bterms = bterms, 
+      get_data2_autocor(x$formula)
+    )
+  }
+  if (version <= "2.11.2") {
+    # ordering after IDs matches the order of the posterior samples 
+    # if multiple IDs are used for the same grouping factor (#835)
+    x$ranef <- x$ranef[order(x$ranef$id), , drop = FALSE]
+  }
+  if (version <= "2.11.4") {
+    # 'cats' is stored inside ordinal families again
+    if (is_ordinal(x$formula)) {
+      x$formula <- SW(validate_formula(x$formula, data = x$data))
+    }
+  }
   x
 }
 
 # restructure models fitted with brms 1.x
 restructure_v1 <- function(x) {
-  version <- x$version$brms
+  version <- get_restructure_version(x)
   if (version < "1.0.0") {
     warning2(
       "Models fitted with brms < 1.0 are no longer offically ",
@@ -149,7 +171,7 @@ restructure_v1 <- function(x) {
   x$nonlinear <- x$partial <- x$threshold <- NULL
   bterms <- parse_bf(formula(x))
   x$data <- rm_attr(x$data, "brmsframe")
-  x$data <- update_data(x$data, bterms) 
+  x$data <- validate_data(x$data, bterms) 
   x$ranef <- tidy_ranef(bterms, model.frame(x))
   if ("prior_frame" %in% class(x$prior)) {
     class(x$prior) <- c("brmsprior", "data.frame") 
@@ -205,6 +227,20 @@ restructure_v1 <- function(x) {
   x
 }
 
+# get version with which a brmsfit object was restructured
+get_restructure_version <- function(x) {
+  stopifnot(is.brmsfit(x))
+  out <- x$version$restructure
+  if (!is.package_version(out)) {
+    # models restructured with brms 2.11.1 store it as an attribute
+    out <- attr(x, "restructured", exact = TRUE) 
+  }
+  if (!is.package_version(out)) {
+    out <- x$version$brms
+  }
+  out
+}
+
 # convert old model formulas to brmsformula objects
 restructure_formula <- function(formula, nonlinear = NULL) {
   if (is.brmsformula(formula) && is.formula(formula)) {
