@@ -138,6 +138,18 @@ validate_stanvars <- function(x) {
   x
 }
 
+# add new stanvars to a brmsfit object
+add_new_stanvars <- function(x, newdata2) {
+  stopifnot(is.brmsfit(x))
+  stanvars_data <- subset_stanvars(x$stanvars, block = "data")
+  for (name in names(stanvars_data)) {
+    if (name %in% names(newdata2)) {
+      x$stanvars[[name]]$sdata <- newdata2[[name]]
+    }
+  }
+  x
+}
+
 #' @export
 c.stanvars <- function(x, ...) {
   dots <- lapply(list(...), validate_stanvars)
